summaryrefslogtreecommitdiffstats
path: root/akregator/src/listtabwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/listtabwidget.h')
-rw-r--r--akregator/src/listtabwidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/akregator/src/listtabwidget.h b/akregator/src/listtabwidget.h
index f720d36f..1dd4d92e 100644
--- a/akregator/src/listtabwidget.h
+++ b/akregator/src/listtabwidget.h
@@ -50,7 +50,7 @@ Q_OBJECT
public:
- ListTabWidget(TQWidget* tqparent=0, const char* name=0);
+ ListTabWidget(TQWidget* parent=0, const char* name=0);
virtual ~ListTabWidget();
enum ViewMode { single, /* horizontalTabs, */ verticalTabs };
@@ -72,7 +72,7 @@ public slots:
void slotItemBegin();
/** select last item in the list */
void slotItemEnd();
/** go to tqparent item */
void slotItemLeft();
/** go to first child */
void slotItemRight();
@@ -72,7 +72,7 @@ public slots:
/** select last item in the list */
void slotItemEnd();
- /** go to tqparent item */
+ /** go to parent item */
void slotItemLeft();
/** go to first child */